@@ -2,6 +2,6 @@
 # Configuration file for using the gdk-pixbuf library in Xlib applications
 #
 GDK_PIXBUF_XLIB_LIBDIR="-L/usr/X11R6/lib"
-GDK_PIXBUF_XLIB_LIBS="-L/usr/local/lib -lgmodule12 -lglib12 -ldl -lgdk_pixbuf_xlib -ltiff -ljpeg -lz -ljpeg -lpng -lz "
+GDK_PIXBUF_XLIB_LIBS="-L/usr/local/lib -lgmodule12 -lglib12 -ldl -lgdk_pixbuf_xlib "
 GDK_PIXBUF_XLIB_INCLUDEDIR="-I/usr/X11R6/include -I/usr/X11R6/include/gtk12 -I/usr/local/include/glib12 -I/usr/local/include -I/usr/X11R6/include"
-MODULE_VERSION="gdk-pixbuf-0.9.0"
+MODULE_VERSION="gdk-pixbuf-0.11.0"
